@@ -2,6 +2,7 @@
 
 import warnings
 
+from mc_nag.base_utils.exceptions import MissingAttributeError
 from mc_nag.base_utils.metaclasses import RequiredAttributeDefinitionMeta
 
 ERROR = 'ERROR'
@@ -85,7 +86,7 @@ class BaseRule(metaclass=RequiredAttributeDefinitionMeta):
         missing_attributes = [attr for attr in self.required_attributes
                               if getattr(self, attr) is None]
         if missing_attributes:
-            raise NotImplementedError(
+            raise MissingAttributeError(
                 f'Class \'{self.__class__.__name__}\' must define ' +  # noqa: W504
                 f'{missing_attributes} attribute(s)!'
             )
@@ -98,7 +99,7 @@ class BaseRule(metaclass=RequiredAttributeDefinitionMeta):
 
         :return: List of violating resource objects.
         """
-        raise NotImplementedError(
+        raise MissingAttributeError(
             f'Class \'{self.__class__.__name__}\' must implement an ' +  # noqa: W504
             'evaluate() method with logic to implement rule!'
         )
