@@ -12,7 +12,8 @@ BCOLORS = {
     'ERROR': '\033[91m',
     'ENDC': '\033[0m',
     'BOLD': '\033[1m',
-    'UNDERLINE': '\033[4m'
+    'UNDERLINE': '\033[4m',
+    'CYAN': '\033[96m'
 }
 
 
@@ -89,17 +90,12 @@ class OutputPrinter:
                     print(f'{left_margin} {line}')
 
             print()
-            print(f'{BCOLORS["HEADER"]}{"Report":30}{BCOLORS["ENDC"]}')
-            print(''.rjust(30, '-'))
+            print(f'{BCOLORS["UNDERLINE"]}{BCOLORS["HEADER"]}{"Template Report":15}{BCOLORS["ENDC"]}')
             for severity in sorted(counts):
                 print(
-                    f'{BCOLORS[severity]}{severity:{left_pad}}{BCOLORS["ENDC"]} : ' +  # noqa: W504
+                    f'- {BCOLORS[severity]}{severity:{left_pad}}{BCOLORS["ENDC"]} : ' +  # noqa: W504
                     f'{counts[severity]:{right_pad}}'
                 )
-            print(f'\n{BCOLORS["HEADER"]}{"Rules Evaluated":30}{BCOLORS["ENDC"]}')
-            print(''.rjust(30, '-'))
-            for rule in _sort_rules(rules):
-                print(rule.__name__)
         else:
             print(f'{BCOLORS["OKGREEN"]}No violations{BCOLORS["ENDC"]} 🎉')
 
