@@ -88,23 +88,29 @@ class RuleEvaluator:
         """
         if not self.rule_set:
             return None
+
         # Dict to hold values for duplicate checking
-        rule_table = []
         dupe_rules = []
         rev_dict = {}
 
+        # Instantiate rules to validate base structural requirements
+        for rule in self.rule_set:
+            _ = rule(None)
+
+        # Sort rules by ID
+        sorted_rules = sorted(self.rule_set, key=lambda x: x.rule_id)
+
         # Gather table information & print
         print(
             tabulate(
-                [[rule.rule_id, rule.__name__]
-                    for rule in sorted(self.rule_set, key=lambda x: x.rule_id)],
+                [[rule.rule_id, rule.__name__] for rule in sorted_rules],
                 headers=["Rule ID", "Rule Name"],
                 tablefmt=TABULATE_FORMAT
             )
         )
 
         # Find duplicate rule IDs
-        for rule in sorted(self.rule_set, key=lambda x: x.rule_id):
+        for rule in sorted_rules:
             rev_dict.setdefault(rule.rule_id, set()).add(
                 f'{rule.__name__} ({rule.__module__}.py)'
             )
