@@ -2,11 +2,12 @@
 
 import re
 from pytest import fixture, raises
-from mc_nag.base_utils.exceptions import InvalidParameter
+from mc_nag.base_utils.exceptions import (
+    InvalidParameter,
+    MissingAttributeError
+)
 from mc_nag.base_utils import read_template_file
 from mc_nag.base_utils.models.rule import (
-    BaseRule,
-    ERROR as RULE_ERROR,
     WARNING as RULE_WARNING
 )
 from mc_nag.base_utils.models.rule_directory import RuleDirectoryManager
@@ -16,6 +17,7 @@ from tests.rules.custom.custom_rule_for_option_testing import \
     CustomPlatformRule
 from tests.rules.with_params.some_threshold_rule import \
     RuleWithSomeThresholdParameter
+from tests.rules.bad.bad_rule import BadRule
 from tests.fixtures import TestTemplate
 
 # pylint: disable=redefined-outer-name
@@ -49,6 +51,12 @@ def rule_dir_manager_std_and_custom(custom='tests/rules/custom'):
     return RuleDirectoryManager(True, 'tests/rules/standard', custom)
 
 
+@fixture(scope='module')
+def rule_dir_manager_bad():
+    """Return bad rules only."""
+    return RuleDirectoryManager(True, 'tests/rules/bad', None)
+
+
 @fixture(scope='module')
 def custom_only_rule_dir_manager():
     """Return only custom rules."""
@@ -119,20 +127,11 @@ def test_rule_evaluator_failing_rule(invalid_template_model, rule_dir_manager_st
 
 def test_rule_evaluator_bad_rule(invalid_template_model, rule_dir_manager):
     """Sad Path: Ensure we raise an exception for a bad rule class."""
-    class BadRule(BaseRule):  # pylint: disable=abstract-method
-        """Bad rule for testing."""
-
-        rule_id = 'BAD'
-        description = 'Bad rule.'
-        severity = RULE_ERROR
-        category_tags = {"custom-resource"}
-        source_tags = {"stelligent"}
-
     rule_evaluator = RuleEvaluator(invalid_template_model,
                                    rule_dir_manager)
     rule_evaluator.rule_set = set([BadRule])
 
-    with raises(NotImplementedError, match="'BadRule' must define"):
+    with raises(MissingAttributeError, match="'BadRule' must define"):
         _, _, _ = rule_evaluator.evaluate_rules()
 
 
@@ -158,6 +157,22 @@ def test_rule_evaluator_display_rules_with_dupes(capsys, rule_dir_manager_std_an
     )
 
 
+def test_rule_evaluator_display_rules_bad(rule_dir_manager_bad):
+    """Sad Path: Display rules with duplicates."""
+    with raises(MissingAttributeError, match=r"Class .* must define .* attribute\(s\)!"):
+        RuleEvaluator(None, rule_dir_manager_bad).display_rules()
+
+
+def test_rule_evaluator_display_rules_no_rules(capsys, rule_dir_manager):
+    """Sad Path: Display evaluator without rules."""
+    rule_evaluator = RuleEvaluator(None, rule_dir_manager)
+    rule_evaluator.rule_set = set()
+    rule_evaluator.display_rules()
+
+    captured = capsys.readouterr()
+    assert captured.out == ''
+
+
 def test_rule_evaluator_rule_params(capsys, valid_template_model):
     """Happy Path: Ensure we can evaluate a rule with parameters passed."""
     some_threshold = 10
